from __future__ import annotations

import sys
from dataclasses import dataclass
from pathlib import Path

if sys.version_info > (3, 11):
    from typing import Self
else:
    from typing_extensions import Self

from ozi_core import __version__ as __version__

core_version: str
HEADER: str
CONF_PATH: Path

@dataclass(init=False, kw_only=True)
class ConfigBase:
    def __init__(self: Self, **kwargs: dict[str, str | list[str] | bool | None]) -> None:
        ...

@dataclass(init=False, kw_only=True)
class OziInteractiveConfig(ConfigBase):
    """General config options for dialog-based CLI."""

    language: str | None = ...

@dataclass(init=False, kw_only=True)
class OziFixConfig(ConfigBase):
    """Persistent ``ozi-fix interactive`` settings."""

    copyright_head: str | None = ...
    pretty: bool | None = ...
    strict: bool | None = ...
    update_wrapfile: bool | None = ...

@dataclass(init=False, kw_only=True)
class OziNewConfig(ConfigBase):
    """Persistent ``ozi-new interactive`` settings."""

    allow_file: list[str] | None = ...
    author: str | None = ...
    author_email: str | None = ...
    ci_provider: str | None = ...
    check_package_exists: bool | None = ...
    copyright_head: str | None = ...
    enable_cython: bool | None = ...
    enable_uv: bool | None = ...
    github_harden_runner: bool | None = ...
    maintainer: str | None = ...
    maintainer_email: str | None = ...
    language: list[str] | None = ...
    readme_type: str | None = ...
    strict: bool | None = ...
    verify_email: bool | None = ...
    update_wrapfile: bool | None = None

@dataclass(init=False, kw_only=True)
class OziConfig(ConfigBase):
    """Persistent ``ozi-* interactive`` settings."""

    fix: OziFixConfig = ...
    new: OziNewConfig = ...
    interactive: OziInteractiveConfig = ...

def read_user_config() -> OziConfig: ...
def write_user_config(data: OziConfig) -> None: ...
